@@ -4,31 +4,30 @@ use warnings;
 
 use Getopt::Std;
 my %opts;
-getopts('i:s:d:p:', \%opts);
+getopts('i:I:p:d:', \%opts);
 
-die "Usage: send-syn.pl [-i DEV ] [ -s SRC_IP ] -d DST_IP -p DST_PORT\n"
-   unless $opts{d} && $opts{p};
+die "Usage: send-syn.pl -i dstIp -p dstPort [ -I srcIp ] [ -d device ]\n"
+   unless $opts{i} && $opts{p};
 
-#$Net::Pkt::Debug++;
 $Net::Pkt::Debug = 3;
 
 # Overwrite autochosen one
-$Net::Pkt::Dev = $opts{i};
-$Net::Pkt::Ip = $opts{s};
+$Net::Pkt::Dev = $opts{d};
+$Net::Pkt::Ip  = $opts{I};
 
 use Net::Pkt::DescL3;
-my $desc = Net::Pkt::DescL3->new(ipDst => $opts{d});
+my $desc = Net::Pkt::DescL3->new(ipDst => $opts{i});
 
 use Net::Pkt::Quick;
 my $frame = Net::Pkt::Quick->tcpSyn(
-   ipSrc => $Net::Pkt::Ip,
-   ipDst => $opts{d},
+   ipSrc   => $Net::Pkt::Ip,
+   ipDst   => $opts{i},
    dstPort => $opts{p},
 );
 
 use Net::Pkt::Dump;
 my $dump = Net::Pkt::Dump->new(
-   filter => $frame->getFilter,
+   filter             => $frame->getFilter,
    unlinkAfterAnalyze => 1,
 );
 
